@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """The nsinterface class.
 
-$Id: checktocontain.py 51874 2008-10-20 17:22:49Z cray $
+$Id: checktocontain.py 52247 2008-12-29 16:54:17Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51874 $"
+__version__ = "$Revision: 52247 $"
 
 from zope.interface import implements, implementedBy
 from zope.traversing.interfaces import ITraversable
@@ -27,21 +27,15 @@ class CheckToContain(FalseCheckToContain):
 
     def traverse(self,name,ignored) :
         """ Return True in name class can be contained in context """
-        print 1
         klass = name2klass(name)
-        print 2
         parent = implementedBy(klass).get('__parent__')
-        print 3
         if parent is not None :
-            print 4
             try :
-                print 5
                 parent.validate(self.context)        
-                print 6
             except ConstraintNotSatisfied :
-                print 7
                 return False 
-        print 8                
+            except :
+                return True
         return True
         
         
